#! /usr/bin/env python2
# -*- coding: utf-8; -*-

'''
Convert a sequence of input frames to an HDF5 video sequence.
'''

# Copyright © INRIA Sophia Antipolis – Méditerranée
# Author: Émilien Tlapale <emilien@tlapale.com>
# 
# This software is a computer program whose purpose is to [describe
# functionalities and technical features of your software].
# 
# This software is governed by the CeCILL-C license under French law and
# abiding by the rules of distribution of free software.  You can  use, 
# modify and/ or redistribute the software under the terms of the CeCILL-C
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info". 
# 
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability. 
# 
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or 
# data to be ensured and,  more generally, to use and operate it in the 
# same conditions as regards security. 
# 
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL-C license and that you accept its terms.


from optparse import OptionParser

from numpy import *
from scipy import *
import h5py

from PIL import Image, ImageOps


if __name__ == '__main__':
    # Parse the command line arguments
    # Usage: frames2hdf.py -o test.h5 frame-001.png frame-002.png ...
    parser = OptionParser()
    parser.add_option('-o', '--hdf-file', dest='hdf_file',
                      default='out.h5', help='Output to HDF_FILE')
    parser.add_option('-d', '--dataset', dest='dataset', default='stimulus',
                      help='Write to DATASET inside HDF_FILE')
    parser.add_option('-m', '--mask', dest='mask', default=None,
                      help='Mask to be used')
    options, args = parser.parse_args()

    
    # Get input info
    depth = len(args)
    if depth == 0:
        exit('Need at least one frame as input')
    img = ImageOps.grayscale(Image.open(args[0]))
    width, height = img.size

    # Prepare output
    hf = h5py.File(options.hdf_file, 'a')
    o = hf.create_dataset(options.dataset, [depth, height, width])
    
    # Process each frame
    for t in xrange(depth):
        print 'Time', t
        # Read the frame
        img = ImageOps.grayscale(Image.open(args[t]))
        if img.size[0] != width or img.size[1] != height:
            exit('All frames should be the same size')
        i = array(img.getdata(), dtype=float32)
        i.shape = height, width
        
        # Normalize
        m, M = i.min(), i.max()
        i = (i - m) / (M - m)
        
        o[t] = i
